@@ -134,7 +134,7 @@ feh_menu *feh_menu_new(void)
 	menus = l;
 
 	if (!bg) {
-		feh_load_image_char(&bg, opt.menu_bg);
+		feh_load_image_char(&bg, PREFIX "/share/feh/images/menubg_default.png");
 		if (bg) {
 			border.left = border.right = border.top = border.bottom
 				= 4;
