@@ -452,6 +452,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 			home = getenv("HOME");
 			if (home) {
 				FILE *fp;
+				int fd;
 				char *path;
 				char *absolute_path;
 				struct stat s;
@@ -462,7 +463,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 				} else {
 					fputs("#!/bin/sh\n", fp);
 					fputs(cmdargv[0], fp);
-					fputs(" --bg-", fp);
+					fputs(" --no-fehbg --bg-", fp);
 					if (centered)
 						fputs("center", fp);
 					else if (scaled)
@@ -519,11 +520,11 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 						free(absolute_path);
 					}
 					fputc('\n', fp);
-					fclose(fp);
-					stat(path, &s);
-					if (chmod(path, s.st_mode | S_IXUSR | S_IXGRP) != 0) {
+					fd = fileno(fp);
+					if (fstat(fd, &s) != 0 || fchmod(fd, s.st_mode | S_IXUSR | S_IXGRP) != 0) {
 						weprintf("Can't set %s as executable", path);
 					}
+					fclose(fp);
 				}
 				free(path);
 			}
