@@ -116,8 +116,17 @@ struct __winwidget {
 	time_t click_start_time;
 
 	unsigned char has_rotated;
+
+#ifdef HAVE_INOTIFY
+	int inotify_wd;
+#endif
 };
 
+#ifdef HAVE_INOTIFY
+void winwidget_inotify_remove(winwidget winwid);
+void winwidget_inotify_add(winwidget winwid, feh_file * file);
+#endif
+
 int winwidget_loadimage(winwidget winwid, feh_file * filename);
 void winwidget_show(winwidget winwid);
 void winwidget_show_menu(winwidget winwid);
